@@ -70,7 +70,7 @@ def create_project_on_fileserver(project, internal=False, deal=None):
         deal_mv = os.path.join(deal_dir, "MV")
 
         if os.path.isdir(deal_go):
-            copytree(deal_go, project_go)
+            copytree(deal_go, project_go, dirs_exist_ok=True)
 
         if os.path.isdir(deal_mv):
             copytree(deal_mv, project_mv, dirs_exist_ok=True)
