@@ -33,14 +33,9 @@ def create_new_project(session):
 
     clearConsole()
     num = None
-<<<<<<< HEAD
-
-    if get_yes_no("Do you have a deal number? 💁‍♀️"):
-=======
     dealnumber = None
     deal = None
     if get_yes_no("Do you have a deal number?"):
->>>>>>> 781162e1d59cabddd9833a2f99424c6f502bf494
         while True:
             dealnumber = input("👀 Enter deal number: ")
             try:
@@ -136,11 +131,7 @@ def create_new_project(session):
 
     if dest_folder is None:
         click.secho(
-<<<<<<< HEAD
-            f"😔 could not find a 'Projects' folder under team {team['name']}", fg="red")
-=======
             f"could not find a 'Projects' folder for team {team['name']}", fg="red")
->>>>>>> 781162e1d59cabddd9833a2f99424c6f502bf494
         quit()
     if client is None:
         while True:
@@ -346,11 +337,7 @@ def create_new_project(session):
 
     session.commit()
 
-<<<<<<< HEAD
     print(f"✅ Succesfully created {project_name} for {team['name']}")
-=======
-    print(f"Succesfully created {project_name} for {team['name']}")
->>>>>>> 781162e1d59cabddd9833a2f99424c6f502bf494
     if deal is not None:
         print(f"Based on deal {deal}")
     print(f"--- creating objects for {project_name} on ftrack")
